==> ws-v3.50.4-src.tar.gz: ws-v3.50-4/src/sheet/English.cpp <==
  WSGIappLocaleSet()->setLocaleString("C","","");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Row Counter", "Row Counter");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Column Counter", "Column Counter");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Row Counter", "Fixed Row Counter");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Column Counter","Fixed Column Counter");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Grid Line Type","Grid Line Type");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Cell Default Width","Cell Default Width");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Cell Default Height","Cell Default Height");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Cell Height","Fixed Cell Height");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Cell Default Font No.","Cell Default Font No.");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Cell Default Font No.","Fixed Cell Default Font No.");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Edit Enabled", "Edit Enabled");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Cell Horizontal number drawing","Fixed Cell Horizontal number drawing");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Cell Vertical number drawing","Fixed Cell Vertical number drawing");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Sheet Back Color","Sheet Back Color");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Cell Default Back Color","Cell Default Back Color");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Cell Default Text Color","Cell Default Text Color");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Cell Back Color","Fixed Cell Back Color");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Cell Text Color","Fixed Cell Text Color");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Grid Color","Grid Color");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Select Item","Database Select Item");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Sort Item1","Database Sort Item1");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Sort1","Database Sort1");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Sort Item2","Database Sort Item2");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Sort2","Database Sort2");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Sort Item3","Database Sort Item3");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Sort3","Database Sort3");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Select SQL","Database Select SQL");
  WSGIappLocaleSet()->setLocaleString("C","X:WSSTR ASC","ASC");
  WSGIappLocaleSet()->setLocaleString("C","X:WSSTR DESC","DESC");

  WSGIappLocaleSet()->setLocaleString("C","X:WSSTR None","NONE");
  WSGIappLocaleSet()->setLocaleString("C","X:WSSTR Horz","HORZ");
  WSGIappLocaleSet()->setLocaleString("C","X:WSSTR Vert","VERT");
  WSGIappLocaleSet()->setLocaleString("C","X:WSSTR Both","BOTH");

==> ws-v3.70.8-src.tar.gz: ws-v3.70-8/src/sheet/English.cpp <==
  WSGIappLocaleSet()->setLocaleString("C","","");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Row Counter", "Row Counter");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Column Counter", "Column Counter");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Row Counter", "Fixed Row Counter");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Column Counter","Fixed Column Counter");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Grid Line Type","Grid Line Type");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Cell Default Width","Cell Default Width");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Cell Default Height","Cell Default Height");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Cell Height","Fixed Cell Height");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Cell Default Font No.","Cell Default Font No.");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Cell Default Font No.","Fixed Cell Default Font No.");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Edit Enabled", "Edit Enabled");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Cell Horizontal number drawing","Fixed Cell Horizontal number drawing");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Cell Vertical number drawing","Fixed Cell Vertical number drawing");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Sheet Back Color","Sheet Back Color");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Cell Default Back Color","Cell Default Back Color");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Cell Default Text Color","Cell Default Text Color");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Cell Back Color","Fixed Cell Back Color");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Fixed Cell Text Color","Fixed Cell Text Color");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR Grid Color","Grid Color");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Select Item","Database Select Item");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Sort Item1","Database Sort Item1");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Sort1","Database Sort1");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Sort Item2","Database Sort Item2");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Sort2","Database Sort2");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Sort Item3","Database Sort Item3");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Sort3","Database Sort3");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Select SQL","Database Select SQL");
  WSGIappLocaleSet()->setLocaleString("C","X:WSSTR ASC","ASC");
  WSGIappLocaleSet()->setLocaleString("C","X:WSSTR DESC","DESC");

  WSGIappLocaleSet()->setLocaleString("C","X:WSSTR None","NONE");
  WSGIappLocaleSet()->setLocaleString("C","X:WSSTR Horz","HORZ");
  WSGIappLocaleSet()->setLocaleString("C","X:WSSTR Vert","VERT");
  WSGIappLocaleSet()->setLocaleString("C","X:WSSTR Both","BOTH");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Cell Auto Resize","Database Connect Cell Auto Resize");
  WSGIappLocaleSet()->setLocaleString("C","p1:WSSTR DB Cell Title","Database Connect Cell Title Display");
